==> gatsby-theme-blog-1.10.3.tgz: package/src/layout/footer.tsx <==
import React, { memo } from 'react';
import { FaGithub } from 'react-icons/fa';

import styled from '@emotion/styled';

import { Theme } from '../../types';
import { useSiteMetadata } from '../hooks';
import { useTheme } from '../theme';

type ContainerProps = {};
type Props = { theme: Theme; author: string } & ContainerProps;

const Component: React.FCX<Props> = memo(({ className, author }) => (
  <footer className={className}>
    <div>
      Copyright©2020.<a href={`https://twitter.com/${author.slice(1)}`}> {author}</a>
    </div>
    <div>
      <a href='https://github.com/hppRC' target='_blank' rel='noopener' aria-label='Github Link'>
        <i>
          <FaGithub />
        </i>
      </a>
      <a
        href='https://github.com/hppRC/gatsby-projects/tree/master/themes/gatsby-theme-blog'
        target='_blank'
        rel='noopener'
      >
        Theme
      </a>
      by{' '}
      <a href='https://hpprc.com' target='_blank' rel='noopener'>
        hpp<span>🌝</span>
      </a>
    </div>
  </footer>
));

const StyledComponent = styled(Component)`
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 10vh;
  > div {
    margin: 0.2rem 0;
    font-weight: 500;
    color: ${({ theme }) => theme.color};
    transition: color 0.3s;
    > a {
      margin-right: 0.5rem;
      color: ${({ theme }) => theme.color};
      text-decoration: none;
      transition: color 0.3s, opacity 0.3s;

      :hover {
        opacity: 0.6;
      }

      > span {
        margin-left: 0.3rem;
      }
    }
  }

  @media screen and (max-width: 1100px) {
  }
  @media screen and (max-width: 768px) {
  }
  @media screen and (max-width: 480px) {
    font-size: 1.2rem;
  }
  @media screen and (max-height: 430px) {
  }
`;

const Container: React.FCX<ContainerProps> = () => {
  const { author } = useSiteMetadata();
  const theme = useTheme();

  return <StyledComponent theme={theme} author={author || 'hppRC'} />;
};

export default memo(Container);

==> gatsby-theme-blog-1.11.0.tgz: package/src/layout/footer.tsx <==
import React, { memo } from 'react';
import { FaGithub } from 'react-icons/fa';

import styled from '@emotion/styled';

import { Theme } from '../../types';
import { useSiteMetadata } from '../hooks';
import { useTheme } from '../theme';

type ContainerProps = {};
type Props = { theme: Theme; author: string } & ContainerProps;

const Component: React.FCX<Props> = memo(({ className, author }) => (
  <footer className={className}>
    <div>
      Copyright©2020.<a href={`https://twitter.com/${author.slice(1)}`}> {author}</a>
    </div>
    <div>
      <a href='https://github.com/hppRC' target='_blank' rel='noopener noreferrer' aria-label='Github Link'>
        <i>
          <FaGithub />
        </i>
      </a>
      <a
        href='https://github.com/hppRC/gatsby-projects/tree/master/themes/gatsby-theme-blog'
        target='_blank'
        rel='noopener noreferrer'
      >
        Theme
      </a>
      by{` `}
      <a href='https://hpprc.com' target='_blank' rel='noopener noreferrer'>
        hpp
        <span role='img' aria-label='title icon'>
          🌝
        </span>
      </a>
    </div>
  </footer>
));

const StyledComponent = styled(Component)`
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 10vh;
  > div {
    margin: 0.2rem 0;
    font-weight: 500;
    color: ${({ theme }) => theme.color};
    transition: color 0.3s;
    > a {
      margin-right: 0.5rem;
      color: ${({ theme }) => theme.color};
      text-decoration: none;
      transition: color 0.3s, opacity 0.3s;

      :hover {
        opacity: 0.6;
      }

      > span {
        margin-left: 0.3rem;
      }
    }
  }

  @media screen and (max-width: 1100px) {
  }
  @media screen and (max-width: 768px) {
  }
  @media screen and (max-width: 480px) {
    font-size: 1.2rem;
  }
  @media screen and (max-height: 430px) {
  }
`;

const Container: React.FCX<ContainerProps> = () => {
  const { author } = useSiteMetadata();
  const theme = useTheme();

  return <StyledComponent theme={theme} author={author || `hppRC`} />;
};

export default memo(Container);
